==> mongodb-src-r4.0.12.tar.gz: mongodb-src-r4.0.12/src/mongo/db/periodic_runner_job_abort_expired_transactions.h <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <memory>

#include "mongo/db/service_context.h"
#include "mongo/stdx/mutex.h"
#include "mongo/util/periodic_runner.h"

namespace mongo {

/**
 * Defines a periodic background job to check for and abort expired transactions.
 * The job will run every (transactionLifetimeLimitSeconds/2) seconds, or at most once per second
 * and at least once per minute.
 */
class PeriodicThreadToAbortExpiredTransactions {
public:
    static PeriodicThreadToAbortExpiredTransactions& get(ServiceContext* serviceContext);

    PeriodicJobAnchor& operator*() const noexcept;
    PeriodicJobAnchor* operator->() const noexcept;

private:
    void _init(ServiceContext* serviceContext);

    mutable stdx::mutex _mutex;
    std::shared_ptr<PeriodicJobAnchor> _anchor;
};

}  // namespace mongo

==> mongodb-src-r4.2.1.tar.gz: mongodb-src-r4.2.1/src/mongo/db/periodic_runner_job_abort_expired_transactions.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <memory>

#include "mongo/db/service_context.h"
#include "mongo/stdx/mutex.h"
#include "mongo/util/periodic_runner.h"

namespace mongo {

/**
 * Defines a periodic background job to check for and abort expired transactions.
 * The job will run every (transactionLifetimeLimitSeconds/2) seconds, or at most once per second
 * and at least once per minute.
 */
class PeriodicThreadToAbortExpiredTransactions {
public:
    static PeriodicThreadToAbortExpiredTransactions& get(ServiceContext* serviceContext);

    PeriodicJobAnchor& operator*() const noexcept;
    PeriodicJobAnchor* operator->() const noexcept;

private:
    void _init(ServiceContext* serviceContext);

    inline static const auto _serviceDecoration =
        ServiceContext::declareDecoration<PeriodicThreadToAbortExpiredTransactions>();

    mutable stdx::mutex _mutex;
    std::shared_ptr<PeriodicJobAnchor> _anchor;
};

}  // namespace mongo
